package com.ynet.life.search.action;

import com.ynet.gene.core.Context;
import com.ynet.gene.core.GENEException;
import com.ynet.life.base.LifeAction;
import com.ynet.life.base.LifeStandard;
import com.ynet.life.base.Trace;
import com.ynet.life.exception.TranFailException;
import com.ynet.life.search.EXTBankNoIndexBuilder;
import com.ynet.life.search.PMSBankNoIndexBuilder;
import com.ynet.life.search.RCUBankNoIndexBuilder;
import java.io.File;
import java.io.IOException;
import org.apache.commons.io.FileUtils;

/* loaded from: com_ynet_life_search_action.jar:com/ynet/life/search/action/BankNoBuildAction.class */
public class BankNoBuildAction extends LifeAction {
    private String bankNoType;

    public String execute(Context context) throws GENEException {
        boolean pmsBuildRet = true;
        boolean extBuildRet = true;
        boolean rcuBuildRet = true;
        if ("1".equals(this.bankNoType) || "0".equals(this.bankNoType)) {
            String indexPath = String.valueOf(LifeStandard.getRootPath()) + LifeStandard.getSelfDefineSettingsValue("pmsBanknoIndexPath");
            File indexDir = new File(indexPath);
            File workDir = new File(indexDir.getParent(), "_" + indexDir.getName());
            if (!isWorking(workDir) && workDir.mkdir()) {
                try {
                    new PMSBankNoIndexBuilder(workDir.getCanonicalPath()).buildIndex();
                    FileUtils.deleteDirectory(indexDir);
                    FileUtils.copyDirectory(workDir, indexDir);
                    FileUtils.deleteDirectory(workDir);
                } catch (Exception empe) {
                    Trace.logError("LifeAction", "构建人行联行号异常", empe);
                    pmsBuildRet = false;
                }
            }
        }
        if ("2".equals(this.bankNoType) || "0".equals(this.bankNoType)) {
            File indexDir2 = new File(String.valueOf(LifeStandard.getRootPath()) + LifeStandard.getSelfDefineSettingsValue("extBanknoIndexPath"));
            File workDir2 = new File(indexDir2.getParent(), "_" + indexDir2.getName());
            if (!isWorking(workDir2) && workDir2.mkdir()) {
                try {
                    new EXTBankNoIndexBuilder(workDir2.getCanonicalPath()).buildIndex();
                    FileUtils.deleteDirectory(indexDir2);
                    FileUtils.copyDirectory(workDir2, indexDir2);
                    FileUtils.deleteDirectory(workDir2);
                } catch (Exception empe2) {
                    Trace.logError("LifeAction", "构建同城交换联行号异常", empe2);
                    extBuildRet = false;
                }
            }
        }
        if ("3".equals(this.bankNoType) || "0".equals(this.bankNoType)) {
            File indexDir3 = new File(String.valueOf(LifeStandard.getRootPath()) + LifeStandard.getSelfDefineSettingsValue("rcuBanknoIndexPath"));
            File workDir3 = new File(indexDir3.getParent(), "_" + indexDir3.getName());
            if (!isWorking(workDir3) && workDir3.mkdir()) {
                try {
                    new RCUBankNoIndexBuilder(workDir3.getCanonicalPath()).buildIndex();
                    FileUtils.deleteDirectory(indexDir3);
                    FileUtils.copyDirectory(workDir3, indexDir3);
                    FileUtils.deleteDirectory(workDir3);
                } catch (Exception empe3) {
                    Trace.logError("LifeAction", "构建农信银联行号异常", empe3);
                    rcuBuildRet = false;
                }
            }
        }
        if (!pmsBuildRet || !extBuildRet || !rcuBuildRet) {
            throw new TranFailException("构建联行号索引失败, 构建结果[人行:" + pmsBuildRet + ", 同城交换:" + pmsBuildRet + ", 农信银:" + pmsBuildRet + "]");
        }
        return "0";
    }

    public String getBankNoType() {
        return this.bankNoType;
    }

    public void setBankNoType(String bankNoType) {
        this.bankNoType = bankNoType;
    }

    private boolean isWorking(File workDir) {
        if (workDir.exists()) {
            long currentTime = System.currentTimeMillis();
            long createTime = workDir.lastModified();
            if ((currentTime - createTime) / 600000 > 0) {
                try {
                    FileUtils.deleteDirectory(workDir);
                } catch (IOException e) {
                    Trace.logError("LifeAction", "构建索引删除临时目录异常", e);
                }
            }
        }
        return workDir.exists();
    }
}
